/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Contreras
Contributor(s): ___________________________________________________.

====================================================================*/

package org.objectweb.ccm.deploytool;

/**
 * This is the CCM XML deployment process
 * 
 * @author <a href="mailto:Christophe.Contreras@lifl.fr">Christophe Contreras</a>
 *
 * @version 0.1
 */

public class DeploymentProcess
     extends org.objectweb.util.cmdline.lib.DefaultConsoleHolder
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** Reference to the assembly unmarshaled object. */
    private org.objectweb.ccm.descriptor.componentassembly.ComponentassemblyBean _assemblyObject;

    /** Reference to the partitionner object. */
    private Partition _partition;

    /** Reference to the connections-maker object. */
    private Connector _connector;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     */
    public DeploymentProcess()
    {
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================

    /**
     * Obtains the partitionner object.
     *
     * @return the partition object.
     */
    public Partition
    getPartition()
    {
        return this._partition;
    }

    /**
     * Obtains the connections-maker object.
     *
     * @return the connector object.
     */
    public Connector
    getConnector()
    {
        return this._connector;
    }

    /**
     * Obtains the assembly unmarshaled object.
     *
     * @return the assembly object.
     */
    public org.objectweb.ccm.descriptor.componentassembly.ComponentassemblyBean
    getAssemblyObject()
    {
        return this._assemblyObject;
    }

    /**
     * Obtains the base directory for any files operations.
     *
     * @return the base directory.
     */
    public static String
    getBaseDir()
    {
        return ("./");
    }

    /**
     * Starts the deployment process.
     *
     * @param filename The assembly file name
     *
     * @return True if the process successes, otherwise False.
     */
    public boolean
    deploy(String filename)
    {
        // get the ORB
        org.omg.CORBA.ORB orb
            = org.objectweb.ccm.CORBA.TheORB
                .getORB();
        getConsole()
            .message("Got the ORB");

        // inits OpenCCM runtime
        org.objectweb.ccm.Components.Runtime.init (orb);
        getConsole()
            .message("OpenCCM runtime is ready");

        //get the object from assembly descriptor
        java.io.File assemblyFile
            = new java.io.File (filename);
        try {
            _assemblyObject
                = org.objectweb.ccm.descriptor.componentassembly.ComponentassemblyImplBean
                    .unmarshalBean(assemblyFile);
        } catch (java.io.IOException exception) {
            getConsole().error("Could not unmarshal the assembly file");
            return false;
        }
        getConsole()
            .message("Got the assembly descriptor");

        //launching the operators
        _connector = new Connector(this);
        _partition = new Partition(this);

        // call for instantiations of components
        if ( !
            _partition.operate()
            )
            return false;

        // switch every component to complete configuration
        for (java.util.Enumeration enum = _partition.elements() ; enum.hasMoreElements() ; )
        {
            try {
                ((org.omg.Components.CCMObject)
                    enum.nextElement())
                        .configuration_complete();
            } catch (java.lang.ClassCastException exception) {

            } catch (org.omg.Components.InvalidConfiguration exception) {
                getConsole().error("Could not switch a CCM Object to configuration complete");
                return false;
            }
        }

        // everything during deployment was OK
        return true;
    }
}
