/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA & USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey, Philippe Merle.
Contributor(s): .

====================================================================*/

package org.objectweb.corba.command.lib;

// Package dependencies.
import org.objectweb.corba.command.api.Generator;
import org.objectweb.util.cmdline.api.CommandLine;
import org.objectweb.util.cmdline.api.OptionArgument;
import org.objectweb.util.cmdline.lib.DefaultOptionArgument;

/**
 * Abstract base class for all compilers/generators.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *
 * @version 0.2
 */

public abstract class CompilerGeneratorBase
              extends CompilerBase
           implements Generator
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The output filename option. */
    private OptionArgument ofile_; // -o <file>

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     * The constructor with the command line manager and the default
     * output file name.
     *
     * @param commandLine The command line manager.
     * @param filename The default output file name.
     */
    public
    CompilerGeneratorBase(CommandLine commandLine,
                          String filename)
    {
        // Calls the CompilerBase constructor.
        super(commandLine);

        // Inits internal state.
        ofile_ = new DefaultOptionArgument(
                        "-o",
                        "outputfile",
                        "Set the output file name, default is " + filename,
                        filename);
        commandLine.addOption(ofile_);
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.util.cmdline.api.Application
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.Application
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.CommandOnIR3
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.CommandOnAST
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.Compiler
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.Generator
    //
    // ==================================================================

    /**
     * Obtains the output file name.
     *
     * @result The output file name.
     */
    public String
    getOutputFileName()
    {
        return ofile_.getArgument();
    }

    /**
     * Indents a file.
     *
     * @param filename The file name to indent.
     *
     * @return True if ok, else false.
     */
    public boolean
    indent(String inputfile)
    {
        org.objectweb.corba.generator.common.lib.Indentor ind =
            new org.objectweb.corba.generator.common.lib.Indentor();
        try
        {
            ind.indent(inputfile);
        }
        catch(java.io.IOException e)
        {
            getConsole().error("I/O Exception with file " + inputfile);
            report_exception(e);
            return false;
        }
        return true;
    }

    // ==================================================================
    //
    // Other public methods.
    //
    // ==================================================================
}
