/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): .

====================================================================*/

package org.objectweb.corba.command.lib;

// Package dependencies.
// import org.objectweb.corba.command.api.IR3Destroy;
import org.objectweb.util.cmdline.lib.DefaultCommandLine;

/**
 * Implementation of the ir3_destroy command.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *
 * @version 0.1
 */

public class IR3Destroy
     extends CommandOnIR3Base
  implements org.objectweb.corba.command.api.IR3Destroy
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public
    IR3Destroy()
    {
        // Calls the CommandOnIR3Base constructor with a command line.
        super(new DefaultCommandLine("ir3_destroy",
                                     "omg_idl_scoped_name",
                                     "Destroy an object from the OpenCCM's Interface Repository",
                                     true));
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.util.cmdline.api.Application
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.Application
    //
    // ==================================================================

    /**
     * Runs the application.
     *
     * @param args The command line arguments.
     *
     * @return The status.
     */
    public int
    run(java.lang.String[] args)
    {
        // Checks availability of the OpenCCM's Interface Repository.
        if(!checkComponentRepository())
            return -1;

        // Destroys the scoped name from the  OpenCCM's Interface Repository.
        if(!destroy(args[0]))
            return -1;

        // All is OK.
        return 0;
    }

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.CommandOnIR3
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.IR3Destroy
    //
    // ==================================================================

    /**
     * Destroys a scoped name from the Interface Repository.
     *
     * @param scoped_name The scoped name to destroy.
     *
     * @return True if ok, else false.
     */
    public boolean
    destroy(String scoped_name)
    {
        // Lookups the scoped name from the OpenCCM's Interface Repository.
        org.omg.CORBA.Contained contained = getComponentRepository().lookup(scoped_name);
        if(contained == null)
        {
            getConsole().error(scoped_name + " not found in the Interface Repository!");
            return false;
        }
 
        // Destroys the scoped name from the OpenCCM's Interface Repository.
        try
        {
            contained.destroy();
        }
        catch(org.omg.CORBA.BAD_INV_ORDER sysExc)
        {
            switch(sysExc.minor)
            {
            case org.objectweb.ccm.IR3.SystemExceptionMinorValues.Dependency:
                getConsole().error(scoped_name +
                    " not destroyed because dependency exits in IFR preventing destruction!");
                return false;

            case org.objectweb.ccm.IR3.SystemExceptionMinorValues.CanNotBeDestroyed:
                getConsole().error(scoped_name +
                                   " not destroyed because indestructible object!");
                return false;
            }
        }

        // All is OK.
        getConsole().message(scoped_name + " destroyed successfully.");
        return true;
    }

    // ==================================================================
    //
    // Static public methods.
    //
    // ==================================================================

    /**
     * The main bootstrap method.
     *
     * @param args The command line arguments.
     */
    public static void
    main(String[] args)
    {
        IR3Destroy ir3destroy = new IR3Destroy();
        ir3destroy.runMain(args);
    }
}
