/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ________________________________________.

====================================================================*/

package org.objectweb.corba.generator.java.ast.lib;

import org.objectweb.corba.generator.java.ast.api.MethodContent;
import java.util.HashMap;

/**
 * This is the representation for java Methode Contents.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</A>
 */

public class MethodContentImpl
  implements MethodContent
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** Velocity macro name */
    private String macro_name_;

    /** The associated Velocity context */
    private org.apache.velocity.context.Context context_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public
    MethodContentImpl()
    {
        // Init internal states
        macro_name_ = null;
        context_ = new org.apache.velocity.VelocityContext();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for org.objectweb.corba.generator.java.ast.api.MethodContent
    //
    // ==================================================================

    /**
     * Set its implementation (a Velocity macro).
     *
     * @param name - The name to set.
     */
    public void
    setMacro(String name)
    {
        macro_name_ = name;
    }

    /**
     * Obtain its implementation (a Velocity macro).
     *
     * @return Its implementation.
     */
    public String
    getMacro()
    {
        return macro_name_;
    }

    /**
     * Add a value to the Velocity Context.
     *
     * @param key - The name to key the provided value with.
     *        value - The corresponding value.
     */
    public void
    addContextValue(String id, Object value)
    {
        context_.put(id, value);
    }

    /**
     * Get the Velocity Context.
     *
     * @return The associated Velocity Context.
     */
    public org.apache.velocity.context.Context
    getContext()
    {
        return context_;
    }
}
