/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ________________________________________.

====================================================================*/

package org.objectweb.corba.generator.java.ast.lib;

import org.objectweb.corba.generator.java.ast.api.ObjectBase;
import java.util.ArrayList;

/**
 * This is a base class for java Objects.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</A>
 */

public class ObjectBaseImpl
  implements ObjectBase
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** Associated comments */
    private ArrayList comments_;

    /** The name */
    private String name_;

    /** The modifier */
    private ModifierKindImpl modifier_;

    /** Is this object final ? */
    private boolean final_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public
    ObjectBaseImpl()
    {
        // Init internal states
        comments_ = new ArrayList();
        name_ = null;
        modifier_ = ModifierKindImpl.mk_public;
        final_ = false;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /**
     * Add a comment.
     *
     * @param comment - The comment to add.
     */
    public void
    addComment(String comment)
    {
        comments_.add(comment);
    }

    /**
     * Get all comments.
     *
     * @return The list of comments.
     */
    public ArrayList
    getComments()
    {
        return comments_;
    }

    /**
     * Set its name.
     *
     * @param name - The name to set.
     */
    public void
    setName(String name)
    {
        name_ = name;
    }

    /**
     * Obtain its name.
     *
     * @return Its name.
     */
    public String
    getName()
    {
        return name_;
    }

    /**
     * Set its modifier.
     *
     * @param mk - The modifier to set.
     */
    public void
    setModifier(ModifierKindImpl mk)
    {
        modifier_ = mk;
    }

    /**
     * Obtain its modifier.
     *
     * @return Its modifier.
     */
    public ModifierKindImpl
    getModifier()
    {
        return modifier_;
    }

    /**
     * Set final this object.
     *
     * @param b - The value to set.
     */
    public void
    setFinal(boolean b)
    {
        final_ = b;
    }

    /**
     * Is this object final ?
     *
     * @return True if it is final, else false.
     */
    public boolean
    isFinal()
    {
        return final_;
    }
}
