/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): .

====================================================================*/

package org.objectweb.corba.generator.psdl.lib;

/** To access all the AST Declaration. */
import org.objectweb.corba.ast.api.Declaration;

/** To access AST DeclarationKind. */
import org.objectweb.corba.ast.api.DeclarationKind;

/** To use GenerationException. */
import org.objectweb.corba.generator.common.lib.GenerationException;


public class PSDL2JavaGenerator
     extends org.objectweb.corba.generator.idl.lib.IDL3Generator
//  implements org.objectweb.corba.generator.psdl.api.PSDL2JavaGeneratorOperations
{

    // ===========================================================
    //
    // Internal State.
    //
    // ===========================================================

    /**
     ** The directory to write in
     **/
    public java.io.File dir_;

    /**
     ** Utility class to convert types in Java
     **/
    public org.objectweb.corba.generator.java.lib.JavaTranslator translator_;

    // ===========================================================
    //
    // Constructors.
    //
    // ===========================================================

    /**
     * The default constructor.
     *
     * @param ast - The Abstract Syntax Tree.
     */

    public PSDL2JavaGenerator(org.objectweb.corba.ast.api.AST ast)
    {
        // Call the IDL3Generator constructor
        super(ast);

        // Init internal states
        dir_ = null;
        translator_ = new org.objectweb.corba.generator.java.lib.JavaTranslator();
    }

    // ===========================================================
    //
    // Internal methods.
    //
    // ===========================================================

    // ===========================================================
    //
    // Public methods.
    //
    // ===========================================================

    /**
     * Initialize the generator.
     **/
    public void
    initialize(String outputdir, String app_name)
    throws GenerationException
    {
        java.util.Vector vect = new java.util.Vector();

        /** Initialize environment **/

        // The ressource path
        vect.add(System.getProperty("ccm.templates"));
        setRessourcePath(vect);

        // Templates to use.
        vect.clear();
        vect.add("common.vm");
        vect.add("idl3.vm");
        vect.add("psdl2java.vm");
        setLibrary(vect);

        // Check the output directory
        dir_ = translator_.mkdir(outputdir);

        // call the common generator init method
        super.init();

        open("tmp.txt", "out");
        /** Initialize velocity context **/
        put("which", app_name);
        put("gen", this);
        put("translator", translator_);
        put("declarator", "");
        put("limited_types" , new Long(org.objectweb.corba.ast.api.DeclarationKind.dk_psdl));

    }

    /**
     * Generates contents of the root scope.
     * Declarations types must match to limited types.
     *
     * @param limited_types - A logical combination of DeclarationKind.
     **/
    public void
    generate()
    throws GenerationException
    {
        java.util.Vector vect = null;

        //vect = getDeclarations(org.objectweb.corba.ast.api.DeclarationKind.dk_psdl);
        //visit(vect);
//        after_generation();
    }

    // ===========================================================
    //
    // Methods for PSDL Mapping.
    //
    // ===========================================================

    /**
     * Visit a single contained declaration
     *
     * @param contained - The declaration to visit.
     * @param extension - used to map id
     **/
    public void
    visitContained(Declaration contained,
                   String extension)
    {
        long limited_types;
        long dk = contained.getDeclKind();
        String id = org.objectweb.corba.ast.lib.DeclarationKindImpl.toString(dk).toUpperCase()+ extension;

        limited_types = DeclarationKind.dk_abstract_storage_home +
                        DeclarationKind.dk_abstract_storage_type +
                        DeclarationKind.dk_storage_home +
                        DeclarationKind.dk_storage_type;
        put("obj", contained);
//         System.err.println("Visit contained :"+contained.getAbsoluteName()+" | "+id+" | "+contained.getPrefix() );

        if ((dk & limited_types) != 0)
        {
            // Create the target directory
            String filename = null;
            java.io.File current_dir = null;
            String separator = System.getProperty("file.separator");

            current_dir = new java.io.File( dir_.getAbsolutePath() +
                                            separator +
                                            translator_.getAsDirectory(contained) );
            try{
                translator_.mkdir(current_dir);
            }catch(GenerationException ex){
                System.err.println(ex.getMessage());
                return;
            }
            filename = new String( current_dir.getAbsolutePath() +
                                   separator +
                                   contained.getName() + ".java" );
            System.out.println("File '" + filename + "' has been generated");

            // create the target file and map
            open(filename, "current");
            map("LICENSE");
            map("PACKAGE");
            map(id);
            close("current");
        }
        else
        {
            map(id);
        }
    }

}
