/*====================================================================

ObjectWeb Util CommandLine Package.
Copyright (C) 2003 INRIA & USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): .

====================================================================*/

package org.objectweb.util.cmdline.lib;

// Package dependencies.
import org.objectweb.util.cmdline.api.Console;
import org.objectweb.util.cmdline.api.ConsoleHolder;

/**
 * Default implementation of the ConsoleHolder interface.
 *
 * This provides the following properties:
 *
 * - Console: The associated console.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *
 * @version 0.1
 */

public class DefaultConsoleHolder
  implements org.objectweb.util.cmdline.api.ConsoleHolder
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The associated console. */
    private Console console_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /** The default constructor. */
    public
    DefaultConsoleHolder()
    {
        // Inits internal state.
        console_ = null;
    }

    /**
     * The constructor with the associated console.
     *
     * @param console The associated console.
     */
    public
    DefaultConsoleHolder(Console console)
    {
        // Inits internal state.
        console_ = console;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.util.cmdline.api.ConsoleHolder
    //
    // ==================================================================

    /**
     * Obtains the associated console.
     *
     * @return The associated console.
     */
    public Console
    getConsole()
    {
        return console_;
    }

    /**
     * Sets the associated console.
     *
     * @param console The associated console.
     */
    public void
    setConsole(Console console)
    {
        console_ = console;
    }
}
