/*====================================================================

ObjectWeb Util Preprocessor Package.
Copyright (C) 2003 INRIA & USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.cpp.lib;

// Package dependencies.
import org.objectweb.util.cpp.api.Preprocessor;
import org.objectweb.util.cpp.api.PreprocessorOption;
import org.objectweb.util.cmdline.lib.DefaultOptionBase;

/**
 * Base abstract implementation for Preprocessor Option objects.
 *
 * Subclasses must implement the consume method.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *
 * @version 0.1
 */

public abstract class PreprocessorOptionBase
              extends DefaultOptionBase
           implements PreprocessorOption
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The preprocessor. */
    private Preprocessor preprocessor_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /** The default constructor. */
    public
    PreprocessorOptionBase()
    {
        // Calls the DefaultOptionBase constructor.
        super();

        setArguments(new String[0]);
        setMandatory(false);

        // Inits internal state.
        preprocessor_ = null;
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for interface org.objectweb.util.cmdline.api.Option
    //
    // ==================================================================

    /**
     * Checks the current command line argument.
     *
     * @param current The current command line argument.
     *
     * @return true if the option accepts this argument.
     */
    public boolean
    check(String current)
    {
      String baseOptionLabel = getBaseOptionLabel();

        if (!current.startsWith(baseOptionLabel))
        {
            return false;
        }

        consumeOption(current.substring(baseOptionLabel.length()));
        return true;
    }

    /**
     * Consumes command line arguments from an iterator.
     *
     * @param iterator The command line argument iterator.
     */
    public void
    consume(org.objectweb.util.cmdline.api.Iterator iterator)
    {
        // Nothing to do.
    }

    // ==================================================================
    //
    //  Public methods for org.objectweb.util.cpp.api.PreprocessorHolder
    //
    // ==================================================================

    /**
     * Obtains the associated preprocessor.
     *
     * @return The associated preprocessor.
     */
    public Preprocessor
    getPreprocessor()
    {
        return preprocessor_;
    }

    /**
     * Sets the associated preprocessor.
     *
     * @param preprocessor The associated preprocessor.
     */
    public void
    setPreprocessor(Preprocessor preprocessor)
    {
        preprocessor_ = preprocessor;
    }

    // ==================================================================
    //
    //  Public methods for org.objectweb.util.cpp.api.PreprocessorOption
    //
    // ==================================================================

    /**
     * Gets the base option label.
     *
     * @return The base option label.
     */
    abstract public String
    getBaseOptionLabel();

    /**
     * Consumes the option.
     *
     * @param current The option value.
     */
    abstract public void
    consumeOption(String current);

    // ==================================================================
    //
    // Other public methods.
    //
    // ==================================================================
}
