@echo off
rem # ====================================================================
rem #
rem # OpenCCM: The Open CORBA Component Model Platform
rem # Copyright (C) 2000-2002 USTL - LIFL - GOAL
rem # Contact: openccm-team@objectweb.org
rem #
rem # This library is free software; you can redistribute it and/or
rem # modify it under the terms of the GNU Lesser General Public
rem # License as published by the Free Software Foundation; either
rem # version 2.1 of the License, or any later version.
rem #
rem # This library is distributed in the hope that it will be useful,
rem # but WITHOUT ANY WARRANTY; without even the implied warranty of
rem # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
rem # Lesser General Public License for more details.
rem #
rem # You should have received a copy of the GNU Lesser General Public
rem # License along with this library; if not, write to the Free Software
rem # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
rem # USA
rem #
rem # Initial developer(s): Marc Navarro (mnavarro@wins.uva.nl),
rem #                       Philippe Merle.
rem # Contributor(s): Christophe Demarey, Jerome Offroy.
rem #
rem # ====================================================================
rem #
rem #  Starting a Java Component Server.
rem #
rem # ====================================================================

setlocal

rem #  =====================
rem #  Compute Command Line
rem #  =====================

set /a nb_args=0
for %%i in (%*) do set /a nb_args=nb_args+1

if %nb_args% lss 1 goto help

set /a nb=0
set with_ots="false"
set with_trace="false"
set services_list=

:initial
if "%1" == "-h" goto help
if "%1" == "--ots" goto ots
if "%1" == "--trace" goto trace
if %nb% geq %nb_args% (goto end_command_line) else (goto arguments)

:ots
set with_ots="true"
set services_list=%services_list% Transactionnal
shift
set /a nb=nb+1
goto initial

:trace
set with_trace="true"
set services_list=%services_list% Trace
shift
set /a nb=nb+1
goto initial

:arguments
set command_args=%command_args% %1
set server_name=%1
shift
set /a nb=nb+1
goto initial

:help
echo usage: jcs_start [--ots] [--trace] ^<server_name^>
goto :eof

:end_command_line

set JCS_PATH=%OpenCCM_CONFIG_DIR%\ComponentServers\%server_name%

rem #  =============
rem #  JCS started ?
rem #  =============

rem # Check if this Java Component Server is already started.
if not exist %JCS_PATH%.PID goto :platform_installed

echo Error: The Component Server %server_name% is already started!
goto :eof

rem #  ============================
rem #  OpenCCM Platform installed ?
rem #  ============================

:platform_installed
call %OpenCCM_HOMEDIR%\bin\ccm_installed
if %CCM_INSTALLED%==0 goto :eof

rem #  ======================
rem #  Name Service started ?
rem #  ======================

rem # Obtain the IOR of the started Name Service.
call ns_ior > %OpenCCM_CONFIG_DIR%\ComponentServers\%server_name%.tmp
for /f %%i in (%OpenCCM_CONFIG_DIR%\ComponentServers\%server_name%.tmp) do set ior_NS=%%i
del %OpenCCM_CONFIG_DIR%\ComponentServers\%server_name%.tmp

rem # Check if a Name Service is started.
if defined ior_NS goto ior_ots

echo Error: The Name Service is not started!
goto :eof

rem #  ===============
rem #  Obtain IOR OTS.
rem #  ===============

:ior_ots

if %with_ots% == "false" goto jcs

rem # Obtain the IOR of the started Transaction Service.
call ots_ior > %OpenCCM_CONFIG_DIR%\ComponentServers\%server_name%.tmp
for /f %%i in (%OpenCCM_CONFIG_DIR%\ComponentServers\%server_name%.tmp) do set ior_OTS=%%i
del %OpenCCM_CONFIG_DIR%\ComponentServers\%server_name%.tmp

rem # Check if a Transaction Service is started.
if defined ior_OTS goto :jcs

echo Error: The Transaction Service is not started!
goto :eof


rem #  ===================================
rem #  Starting the Java Component Server.
rem #  ===================================

:jcs
echo The OpenCCM's Java Component Server %server_name% will be started with [%services_list%]...
rem # Check if the OpenCCM Java Component Server archive directory doesn't exist.
if exist %JCS_PATH%.archive_cache goto cache_exist

echo Creating the %JCS_PATH%.archive_cache directory.
mkdir %JCS_PATH%.archive_cache

:cache_exist
set jvm_args=
set run_id=jcs
if %with_ots% == "false" goto service_trace

rem # Transaction Service
rem #
set jvm_args=-Dior_ots=%ior_OTS%
set run_id=%run_id%_ots

:service_trace
if %with_trace% == "false" goto run
set run_id=%run_id%_trace

:run
echo "Launching an OpenCCM's Java Component Server."
set jvm_args=%jvm_args% -Djcs_path=%JCS_PATH% -Dior_ns=%ior_NS%
set args=--runid %run_id% %server_name% %JCS_PATH%.IOR
launcher fork "%jvm_args%" "%args% %OpenCCM_HOMEDIR%/xml/launcher/JCS.xml" %JCS_PATH%.output %JCS_PATH%.PID

echo "The OpenCCM's Java Component Server %server_name% is started."
