/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Offroy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.corba.trace.PI;

/* MONOLOG import */
import org.objectweb.util.monolog.api.BasicLevel;
import org.objectweb.util.monolog.api.Logger;

/**
 * The Server side interceptor used to log CORBA Server activity
 * @author <a href="mailto:offroy@lifl.fr">offroy@lifl.fr;</a>
 */
public class TraceSI extends org.omg.CORBA.LocalObject 
    implements org.omg.PortableInterceptor.ServerRequestInterceptor {

	protected Logger logger_;

    /**
     * Level of logging for Server side Interceptor
     */
    private short logLevelServer;
    /* TODO change static def of ServerLevelLog */

    /**
     * used to get CORBA call information (server side)
     */
	protected ServerRequestInfoReader srir_;

    /**
     * Constructor
     */
    public TraceSI(int trace_slot, org.omg.PortableInterceptor.ORBInitInfo info) {
        /* MONOLOG logger initialization */
        logger_ = MonologLogger.loggerSI;
        logLevelServer = 1;
        this.srir_ = new ServerRequestInfoReader(logLevelServer);

         if (MonologLogger.enableTrace) 
            logger_.log(BasicLevel.DEBUG, "Init Trace Interceptor CORBA Server Side");
    }

    /**********************************************************************
     * Public Method 
     **********************************************************************/
    /**
     * Called when the server receive a request from a client (before receive_request)
     * @param ri the server request
     */
    public void receive_request_service_contexts(org.omg.PortableInterceptor.ServerRequestInfo ri){
         if (MonologLogger.enableTrace) 
            logger_.log(BasicLevel.INFO, srir_.displayServerRequestInfoMonolog(ri));        
    }

    /**
     * Called when the server receive a request from a client (after receive_request_service_context)
     * @param ri the server request
     */
    public void receive_request(org.omg.PortableInterceptor.ServerRequestInfo ri) {
         if (MonologLogger.enableTrace) 
            logger_.log(BasicLevel.INFO, srir_.displayServerRequestInfoMonolog(ri));
    }

    /**
     * Called when the server send a reply to a client 
     * @param ri the server request
     */
    public void send_reply(org.omg.PortableInterceptor.ServerRequestInfo ri) {
         if (MonologLogger.enableTrace) 
            logger_.log(BasicLevel.INFO, srir_.displayServerRequestInfoMonolog(ri));
    }

    /**
     * Called when the server send an exception to a client 
     * @param ri the server request
     */
    public void send_exception(org.omg.PortableInterceptor.ServerRequestInfo ri) {
         if (MonologLogger.enableTrace) 
           logger_.log(BasicLevel.ERROR, srir_.displayServerRequestInfoMonolog(ri,false));
    }

    /**
     * Called when the server send a message to a client
     *  which is not a reply and not an exception
     * @param ri the server request
     */
    public void send_other(org.omg.PortableInterceptor.ServerRequestInfo ri) {
         if (MonologLogger.enableTrace) 
            logger_.log(BasicLevel.INFO, srir_.displayServerRequestInfoMonolog(ri));
    }

    /**
     * return the name of the Logging Server Interceptor
     */
    public java.lang.String name() {
        return "LoggingServerInterceptor";
    }

    /**
     * Destroy the interceptor.
     */
    public void destroy() {
    }
}
